@@ -1,11 +1,11 @@
 /* -*-c-*- -------------- mixgtk_gen_handlers.c :
  * Implementation of the functions declared in mixgtk_gen_handlers.h
  * ------------------------------------------------------------------
- * Copyright (C) 2001, 2002, 2004, 2006 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002, 2004, 2006, 2007, 2019 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -40,8 +40,8 @@ get_chooser_ (const gchar *title, gboolean src)
         (gtk_file_chooser_dialog_new ("gmixvm",
                                       NULL,
                                       GTK_FILE_CHOOSER_ACTION_OPEN,
-                                      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                      "_Cancel", GTK_RESPONSE_CANCEL,
+                                      "_Open", GTK_RESPONSE_ACCEPT,
                                       NULL));
       src_filter = gtk_file_filter_new ();
       gtk_file_filter_add_pattern (src_filter, "*.mixal");
@@ -185,7 +185,8 @@ on_clear_breakpoints_activate (GtkWidget *w, gpointer data)
 void
 on_save_on_exit_toggle (GtkWidget *w, gpointer data)
 {
-  mixgtk_config_set_autosave (GTK_CHECK_MENU_ITEM (w)->active);
+  gboolean active = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (w));
+  mixgtk_config_set_autosave (active);
 }
 
 void
@@ -193,5 +194,3 @@ on_save_activate (GtkWidget *w, gpointer data)
 {
   mixgtk_config_save ();
 }
-
-
